==> haskell-uri-bytestring-0.2.3.1-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-bytestring
version: 0.2.3.1
id: uri-bytestring-0.2.3.1-LOHiQuolSkuLEbq7Gg2KhJ
key: uri-bytestring-0.2.3.1-LOHiQuolSkuLEbq7Gg2KhJ
license: BSD3
copyright: Soostone Inc.
maintainer: Michael Xavier <michael.xavier@soostone.com>
homepage: https://github.com/Soostone/uri-bytestring
synopsis: Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.
category: Web
author: Doug Beardsley, Michael Xavier
exposed: True
exposed-modules:
    URI.ByteString URI.ByteString.QQ
hidden-modules: URI.ByteString.Lens URI.ByteString.Types
                URI.ByteString.Internal
abi: 17ee393f7a9524a4903260cc925d7585
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/uri-bytestring-0.2.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/uri-bytestring-0.2.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/uri-bytestring-0.2.3.1
hs-libraries: HSuri-bytestring-0.2.3.1-LOHiQuolSkuLEbq7Gg2KhJ
depends:
    attoparsec-0.13.1.0-2ptg9LSVcb1at70Z7RWD3 base-4.9.0.0
    blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S bytestring-0.10.8.1
    containers-0.5.7.1 template-haskell-2.11.0.0
    th-lift-instances-0.1.11-1sD5YjoMgIx3ybpjdu7bXa
haddock-interfaces: /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock
haddock-html: /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-0.2.3.3-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-bytestring
version: 0.2.3.3
id: uri-bytestring-0.2.3.3-Ly7zQaj1bS4SvQXLhjvut
key: uri-bytestring-0.2.3.3-Ly7zQaj1bS4SvQXLhjvut
license: BSD3
copyright: Soostone Inc.
maintainer: Michael Xavier <michael.xavier@soostone.com>
homepage: https://github.com/Soostone/uri-bytestring
synopsis: Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.
category: Web
author: Doug Beardsley, Michael Xavier
exposed: True
exposed-modules:
    URI.ByteString URI.ByteString.QQ
hidden-modules: URI.ByteString.Lens URI.ByteString.Types
                URI.ByteString.Internal
abi: d00a43655fe982920c79db8b77ac22d4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/uri-bytestring-0.2.3.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/uri-bytestring-0.2.3.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/uri-bytestring-0.2.3.3
hs-libraries: HSuri-bytestring-0.2.3.3-Ly7zQaj1bS4SvQXLhjvut
depends:
    attoparsec-0.13.1.0-oc29svN3SiFq1TojBIbwV base-4.9.0.0
    blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S bytestring-0.10.8.1
    containers-0.5.7.1 template-haskell-2.11.0.0
    th-lift-instances-0.1.11-1sD5YjoMgIx3ybpjdu7bXa
haddock-interfaces: /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock
haddock-html: /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
